@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Net::SAML2::SP;
-our $VERSION = '0.66'; # TRIAL VERSION
+our $VERSION = '0.68'; # TRIAL VERSION
 
 use Moose;
 
@@ -396,22 +396,15 @@ sub _generate_key_descriptors {
         && !$self->want_assertions_signed
         && !$self->sign_metadata;
 
+    my $key = $use eq 'signing' ? $self->_cert_text : $self->_encryption_key_text;
+
     return $x->KeyDescriptor(
         $md,
         { use => $use },
         $x->KeyInfo(
             $ds,
-            $x->X509Data(
-                $ds,
-                $x->X509Certificate(
-                    $ds,
-                    $use eq 'signing' ? $self->_cert_text : $self->_encryption_key_text,
-                )
-            ),
-            $x->KeyName(
-                $ds,
-                Digest::MD5::md5_hex($use eq 'signing' ? $self->_cert_text : $self->_encryption_key_text)
-            ),
+            $x->X509Data($ds, $x->X509Certificate($ds, $key)),
+            $x->KeyName($ds, Digest::MD5::md5_hex($key)),
         ),
     );
 }
@@ -472,7 +465,7 @@ Net::SAML2::SP - Net::SAML2::SP - SAML Service Provider object
 
 =head1 VERSION
 
-version 0.66
+version 0.68
 
 =head1 SYNOPSIS
 
